summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/sqlite/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/sqlite/main.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/sqlite/main.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/sqlite/main.c b/tqtinterface/qt4/src/3rdparty/sqlite/main.c
index e420bac..66b3e27 100644
--- a/tqtinterface/qt4/src/3rdparty/sqlite/main.c
+++ b/tqtinterface/qt4/src/3rdparty/sqlite/main.c
@@ -5,7 +5,7 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
@@ -42,7 +42,7 @@ static void corruptSchema(InitData *pData, const char *zExtra){
** This is the callback routine for the code that initializes the
** database. See sqliteInit() below for additional information.
**
** Each callback tqcontains the following information:
**
** argv[0] = "file-format" or "schema-cookie" or "table" or "index"
** argv[1] = table or index name or meta statement type.
@@ -833,7 +833,7 @@ const char *sqlite_error_string(int rc){
case STQLITE_FULL: z = "database is full"; break;
case STQLITE_CANTOPEN: z = "unable to open database file"; break;
case STQLITE_PROTOCOL: z = "database locking protocol failure"; break;
- case STQLITE_EMPTY: z = "table tqcontains no data"; break;
+ case STQLITE_EMPTY: z = "table contains no data"; break;
case STQLITE_SCHEMA: z = "database schema has changed"; break;
case STQLITE_TOOBIG: z = "too much data for one table row"; break;
case STQLITE_CONSTRAINT: z = "constraint failed"; break;
@@ -42,7 +42,7 @@ static void corruptSchema(InitData *pData, const char *zExtra){
** database. See sqliteInit() below for additional information.
**
-** Each callback tqcontains the following information:
+** Each callback contains the following information:
**
** argv[0] = "file-format" or "schema-cookie" or "table" or "index"